@@ -115,7 +115,6 @@ class SHCAPI:
 
         try:
             result = self._post_api_or_fail(api_url, data, wait_seconds + 5)
-            time.sleep(wait_seconds + 5)
         except Exception as e:
             logging.error(f"Failed to start long polling for SALUS Controller: {e}")
             return None
@@ -147,7 +146,7 @@ class SHCAPI:
                 "id": [
                     {
                         "data": device.data,
-                        "sIT600TH": {"SetHoldType": 7 if mode == HVAC_MODE_OFF else 0}
+                        "sIT600TH": {"SetHoldType": 7 if mode == HVAC_MODE_OFF else device.previous_mode}
                     }
                 ]
             }
