@@ -20,6 +20,7 @@ class SALUSThermostat(SALUSDevice):
 
     def __init__(self, api: SHCAPI, raw_device):
         super().__init__(api, raw_device)
+        self._previous_mode = self.preset_mode
 
     @property
     def supported_features(self):
@@ -100,6 +101,11 @@ class SALUSThermostat(SALUSDevice):
 
     async def set_climate_device_preset(self, preset: str):
         await self._api.set_climate_device_preset(self, preset)
+        self._previous_mode = preset
+
+    @property
+    def previous_mode(self):
+        return self._previous_mode
 
 
 MODEL_MAPPING = {
